@@ -1,7 +1,7 @@
 #' @include utils.R
 #' @include mlr_pipeops.R
 #'
-#' @title PipeOp
+#' @title PipeOp Base Class
 #'
 #' @usage NULL
 #' @format Abstract [`R6Class`].
@@ -197,6 +197,7 @@
 #' @name PipeOp
 #' @family mlr3pipelines backend related
 #' @family PipeOps
+#' @seealso https://mlr3book.mlr-org.com/list-pipeops.html
 #' @export
 PipeOp = R6Class("PipeOp",
   public = list(
@@ -327,7 +328,7 @@ PipeOp = R6Class("PipeOp",
         # objects.
         # In the following we also avoid accessing `val$hash` twice, because it could
         # potentially be an expensive AB.
-        if (is.environment(val) && !is.null({vhash = val$hash})) {
+        if (is.environment(val) && !is.null({vhash = get0("hash", val, mode = "any", inherits = FALSE, ifnotfound = NULL)})) {
           vhash
         } else {
           val
